@@ -1,6 +1,6 @@
 package LLVM;
 {
-  $LLVM::VERSION = '0.05';
+  $LLVM::VERSION = '0.06';
 }
 
 use strict;
@@ -15,18 +15,17 @@ LLVM - Perl bindings to the Low Level Virtual Machine
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
     use LLVM;
 
     # create a new LLVM context and a module named "synopsis"
-    my $ctx = LLVM::Context -> new;
-    my $mod = LLVM::Module -> new($ctx, "synopsis");
+    my $mod = LLVM::Module -> new("synopsis");
 
     # create a new function type that takes 2 ints and returns one int
-    my $intt = LLVM::Type -> int($ctx, 32);
+    my $intt = LLVM::Type -> int(32);
     my $funt = LLVM::Type -> func($intt, $intt, $intt);
 
     # add a new function to the module with the just-created type
@@ -39,8 +38,8 @@ version 0.05
     $params -> [1] -> set_name("y");
 
     # create a new entry block for the "add" function and its builder
-    my $blk = $fun -> func_append($ctx, "entry");
-    my $bld = LLVM::Builder -> new($ctx, $blk);
+    my $blk = $fun -> func_append("entry");
+    my $bld = LLVM::Builder -> new($blk);
 
     # create an "add" intruction and use its return value as function return
     my $tmp = $bld -> add($params -> [0], $params -> [1], "tmp");
